package fr.univnantes.alma;

import java.util.LinkedList;
import java.util.List;
import java.util.concurrent.TimeUnit;

public class PlayerController implements Player {

    private String playerName;
    private List<Card> playerCards;
    private MiddlewareClient middlewareClient;
    private int playerMoney;

    private Card chosenCard;
    private int chosenAction;

    public PlayerController(){
        this.playerName = null;
        this.playerCards = new LinkedList<>();
        this.middlewareClient = new MiddlewareClientController();
        this.playerMoney = 0;
    }

    @Override
    public boolean newPlayer(String playerName) {
        if (playerName != null) {
            this.playerName = playerName;
            return true;
        }
        return false;
    }

    @Override
    public boolean connectionGame(String user) {
        return middlewareClient.connectionGame(user);
    }

    @Override
    public boolean disconnectionGame(String user) {
        return middlewareClient.disconnectionGame(user);
    }

    @Override
    public boolean waitServer(int sec){
        try {
            TimeUnit.SECONDS.sleep(sec);
            return true;                            //WIP : attente du serveur par défaut.
        }catch(InterruptedException interruption){
            return false;
        }
    }

    @Override
    public boolean waitPlayer() {
        return false;
    }

    @Override
    public boolean launchGame() {
        return false;
    }

    @Override
    public boolean addCard(Card newCard) {
        if (newCard != null) {
            this.playerCards.add(newCard);
            return true;
        }
        return false;
    }

    @Override
    public boolean addCards(List<Card> newCards) {
        if (newCards != null && newCards.size() > 0) {
            this.playerCards.addAll(newCards);
            return true;
        }
        return false;
    }

    @Override
    public boolean moneyGet(int number) {
        this.playerMoney += number;
        return true;
    }

    @Override
    public boolean chooseCard(Card card) {
        if (this.playerCards.contains(card)) {
            this.chosenCard = card;
            return middlewareClient.chooseCard(card);
        }
        return false;
    }

    @Override
    public boolean chooseAction(int action) {
        if (action >= 1 && action <= 3) {
            this.chosenAction = action;
            return middlewareClient.chooseAction(action);
        }
        return false;
    }

    public List<Card> getPlayerCards() {
        return this.playerCards;
    }

    public Card getChosenCard() {
        return this.chosenCard;
    }

    public int getChosenAction() {
        return this.chosenAction;
    }

    public int getPlayerMoney() {
        return this.playerMoney;
    }
}
