package fr.univnantes.alma;

public interface GameServer {

    /**
     * Connect a player to the game.
     *
     * @param newPlayer The player to connect.
     *
     * @return true if the player has been connected, false otherwise.
     */
    boolean connectionGame(Player newPlayer);

    /**
     * Disconnect a player from the game.
     *
     * @param playerExist The player to disconnect.
     *
     * @return true if the player has been disconnected, false otherwise.
     */
    boolean disconnectionGame(Player playerExist);

    /**
     * Launch the game.
     *
     * @return true if the game has been launched, false otherwise.
     */
    boolean launchGame();

    /**
     * Kick a player from the game.
     *
     * @param user The player to kick.
     *
     * @return true if the player has been kicked, false otherwise.
     */
    boolean autoKickParty(Player user);

    /**
     * Sort the card.
     *
     * @return true if the cards have been sorted, false otherwise.
     */
    boolean cardSort();

    /**
     * Distributes cards according to age.
     *
     * @param age The current age.
     *
     * @return true if the cards have been distributed, false otherwise.
     */
    boolean cardDistribution(int age);

    /**
     * Distributes money to all players.
     *
     * @return true if the money has been distributed, false otherwise.
     */
    boolean moneyDistribution();

    /**
     * Executes actions.
     *
     * @return true if actions has been executed, false otherwise.
     */
    boolean executeActions();

    /**
     * Solve the military conflicts.
     *
     * @return true if the military conflicts has been resolved, false otherwise.
     */
    boolean solveMilitaryConflicts();

    /**
     * End the game.
     *
     * @return true if the game ended correctly, false otherwise.
     */
    boolean gameEnd();
}
