package fr.univnantes.alma;

import java.util.List;

public interface MiddlewareServer {

    /**
     * Creates a new player.
     *
     * @param playerName The name of the player.
     *
     * @return true if the player has been correctly created, false otherwise.
     */
    boolean newPlayer(String playerName);

    /**
     * Wait for all players to join the game. If the timer reaches 0, it launches the game.
     *
     * @param sec The time the server will wait.
     *
     * @return true if the server has waited correctly, false otherwise.
     */
    boolean waitServer(int sec);

    /**
     * Wait for all players to do an action.
     *
     * @return true if all players have done their actions, false otherwise.
     */
    boolean waitPlayer();

    /**
     * Add a card
     *
     * @param newCard The card to add.
     *
     * @return true if the card has been added, false otherwise.
     */
    boolean addCard(Card newCard);

    /**
     * Add a list of cards to the game.
     *
     * @param newCards List of cards to add
     *
     * @return true if cards has been added, false otherwise.
     */
    boolean addCards(List<Card> newCards);

    /**
     * Add an amount of money to the player.
     *
     * @param number The amount of money to add.
     *
     * @return true if the amount of money has been added, false otherwise.
     */
    boolean moneyGet(int number);

    /**
     * Draw 7 cards.
     *
     * @return true if the cards have been drawn, false otherwise.
     */
    boolean draw7Cards();

    /**
     * Give the assign card.
     *
     * @return true if the card has been given, false otherwise.
     */
    boolean giveAssignCards();

    /**
     * End the game.
     *
     * @return true if the game ended correctly, false otherwise.
     */
    boolean gameEnd();

    /**
     * Executes actions.
     *
     * @return true if actions has been executed, false otherwise.
     */
    boolean executeActions();

}
