package fr.univnantes.alma;

import java.util.List;

public interface Player {

    /**
     * Creates a new player.
     *
     * @param playerName The name of the player.
     *
     * @return true if the player has been correctly created, false otherwise.
     */
    boolean newPlayer(String playerName);

    /**
     * Connect a player through his username.
     *
     * @param user The user to connect.
     *
     * @return true if the user has been connected, false otherwise.
     */
    boolean connectionGame(String user);

    /**
     * Disconnect a player through his username.
     *
     * @param user The user to disconnect.
     *
     * @return true if the user has been disconnected, false otherwise.
     */
    boolean disconnectionGame(String user);

    /**
     * Wait for all players to join the game. If the timer reaches 0, it launches the game.
     *
     * @param sec The time the server will wait.
     *
     * @return true if the server has waited correctly, false otherwise.
     */
    boolean waitServer(int sec);

    /**
     * Wait for all players to do an action.
     *
     * @return true if all players have done their actions, false otherwise.
     */
    boolean waitPlayer();

    /**
     * Launch the game.
     *
     * @return true if the game has been launched correctly, false otherwise.
     */
    boolean launchGame();

    /**
     * Add a card
     *
     * @param newCard The card to add.
     *
     * @return true if the card has been added, false otherwise.
     */
    boolean addCard(Card newCard);

    /**
     * Add a list of cards to the game.
     *
     * @param newCards List of cards to add
     *
     * @return true if cards has been added, false otherwise.
     */
    boolean addCards(List<Card> newCards);

    /**
     * Add an amount of money to the player.
     *
     * @param number The amount of money to add.
     *
     * @return true if the amount of money has been added, false otherwise.
     */
    boolean moneyGet(int number);

    /**
     * Choose a card.
     *
     * @param card The card that will be chosen.
     *
     * @return true if the card has been chosen, false otherwise.
     */
    boolean chooseCard(Card card);

    /**
     * The action the player choose.
     *
     * @param action The action number.
     *
     * @return true if the action has been chosen, false otherwise.
     */
    boolean chooseAction(int action);

}
