package fr.univnantes.alma.cards;

import fr.univnantes.alma.Card;

import java.util.Map;

public class CardAge implements Card {

    /**
     * The name of the card.
     */
    private String name;

    /**
     * The type of structure of the card.
     */
    private Structures structure;

    /**
     * The age of the card.
     */
    private int age;

    /**
     * The minimum amount of player required to get this card in the game.
     */
    private int minPlayer;

    /**
     * The cost of the card.
     */
    private Map<Resources, Integer> cost;

    /**
     * The production of the card.
     */
    private Map<Productions, Integer> production;

    /**
     * Constructor of CardAge. A card has a name, a type of structure, a minimum amount of player to be playable,
     * a cost and a production.
     *
     * @param name The name of the card.
     * @param structure The structure type of the card.
     * @param minPlayer The minimum of player required to get this card.
     * @param cost The cost of resources to play the card.
     * @param production The production of resources this card produce.
     */
    public CardAge(String name, Structures structure, int age, int minPlayer, Map<Resources, Integer> cost, Map<Productions,Integer> production) {
        this.name = name;
        this.structure = structure;
        this.age = age;
        this.minPlayer = minPlayer;
        this.cost = cost;
        this.production = production;
    }

    /**
     * Getter of structure.
     *
     * @return The type of structure of the card.
     */
    public Structures getStructure() {
        return structure;
    }

    /**
     * Getter of the age of the card.
     *
     * @return The age of the card.
     */
    public int getAge() {
        return this.age;
    }

    /**
     * Getter of minimum player.
     *
     * @return The minimum player of the card.
     */
    public int getMinPlayer() {
        return minPlayer;
    }

    /**
     * Getter of the map representing the cost of the card.
     *
     * @return The cost of the card.
     */
    public Map<Resources, Integer> getCost() {
        return cost;
    }

    /**
     * Getter of the map representing the production of the card.
     *
     * @return The production of the card.
     */
    public Map<Productions, Integer> getProduction() {
        return production;
    }

    @Override
    public String getName() {
        return this.name;
    }
}
