package fr.univnantes.alma.cards;

public class Productions {

    /**
     * Indicates if the production is a shield production.
     */
    private boolean isShield;

    /**
     * Indicates if the production is a resource production.
     */
    private Resources resources;

    /**
     * Indicates if the production is a scientific field production.
     */
    private ScientificFields scientificFields;

    /**
     * Constructor of Productions. This constructor creates a shield production.
     *
     * @param isShield If the production is a shield production.
     */
    public Productions(boolean isShield) {
        this.isShield = isShield;
        this.resources = null;
        this.scientificFields = null;
    }

    /**
     * Constructor of Productions. This constructor creates a resource production.
     *
     * @param resources The resources the card will produce.
     */
    public Productions(Resources resources) {
        this.isShield = false;
        this.resources = resources;
        this.scientificFields = null;
    }

    /**
     * Constructor of Productions. This constructor creates a scientific field production
     *
     * @param scientificFields The type of scientific field production.
     */
    public Productions(ScientificFields scientificFields) {
        this.isShield = false;
        this.resources = null;
        this.scientificFields = scientificFields;
    }

    /**
     * Getter of shield value.
     *
     * @return true if the card is a shield production, false otherwise
     */
    public boolean isShield() {
        return this.isShield;
    }

    /**
     * Getter of resources.
     *
     * @return The resource of the production, null if it is not a resource.
     */
    public Resources getResources() {
        return this.resources;
    }

    /**
     * Getter of scientific field.
     *
     * @return The scientific field of the production, null if it is not a scientific field.
     */
    public ScientificFields getScientificFields() {
        return this.scientificFields;
    }
}
