package fr.univnantes.alma.cards;

public class Resources {

    /**
     * Indicates if the resource is money.
     */
    private boolean isMoney;

    /**
     * Indicates if the resource is a raw material.
     */
    private RawMaterials rawMaterial;

    /**
     * Indicates if the resource is a raw material.
     */
    private ManufacturedGoods manufacturedGoods;

    /**
     * Constructor of Resources. This constructor creates money.
     *
     * @param isMoney If the resource is money.
     */
    public Resources(boolean isMoney) {
        this.isMoney = isMoney;
        this.rawMaterial = null;
        this.manufacturedGoods = null;
    }

    /**
     * Constructor of Resources. This constructor creates a raw material.
     *
     * @param rawMaterial The type of raw material.
     */
    public Resources(RawMaterials rawMaterial) {
        this.isMoney = false;
        this.rawMaterial = rawMaterial;
        this.manufacturedGoods = null;
    }

    /**
     * Constructor of Resources. This constructor creates a manufactured goods.
     *
     * @param manufacturedGoods The type of manufactured goods.
     */
    public Resources(ManufacturedGoods manufacturedGoods) {
        this.isMoney = false;
        this.rawMaterial = null;
        this.manufacturedGoods = manufacturedGoods;
    }

    /**
     * Getter of money.
     *
     * @return true if the resource is money, false otherwise.
     */
    public boolean isMoney() {
        return this.isMoney;
    }

    /**
     * Getter of raw materials.
     *
     * @return The raw material, null if it is not a raw material.
     */
    public RawMaterials getRawMaterial() {
        return this.rawMaterial;
    }

    /**
     * Getter of manufactured goods.
     *
     * @return The manufactured goods, null if it is not a manufactured goods.
     */
    public ManufacturedGoods getManufacturedGoods() {
        return this.manufacturedGoods;
    }
}
