package fr.univnantes.alma.implement;

import fr.univnantes.alma.*;
import fr.univnantes.alma.cards.CardAge;
import fr.univnantes.alma.cards.CardWonder;
import fr.univnantes.alma.cards.Resources;
import fr.univnantes.alma.messages.Connexion;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

import static fr.univnantes.alma.cards.Structures.*;

public class GameServerImp implements GameServer {
    ArrayList<Player> player;
    boolean isGamePlayed;
    MiddlewareServer middlewareServer;
    ArrayList<Card> cardBank;

    public GameServerImp() {
        this.player= new ArrayList<>();
        this.isGamePlayed=false;
        this.middlewareServer=new MiddlewareServerController(new Connexion("creation middleware server. Hello new Middleware Server"), this);
        this.cardBank = new ArrayList<>(); //TODO : il faut remplir les cards banques
    }

    @Override
    public boolean connectionGame(Player newPlayer) {
        if (this.player.size() >7) {
            return false;
        } else {
            this.player.add(newPlayer);
            return true;
        }
    }

    @Override
    public boolean disconnectionGame(Player playerExist) {
        if (this.player.contains(playerExist)) {
            this.player.remove(playerExist);
            return true;
        } else {
            return false;
        }
    }

    @Override
    public boolean launchGame() {
        if ( (this.player.size()>=3) && (this.player.size()<=7) ){
            isGamePlayed=true;
            return true;
        } else {
            return false;
        }
    }

    @Override
    public boolean autoKickParty(Player user) {
        return this.disconnectionGame(user);
    }

    /*
    Sort cards depending on number of players
     */
    @Override
    public boolean cardSort() {
        int nbPlayer = this.player.size();
        ArrayList<Card> cardBankSorted = new ArrayList<>();
        ArrayList<Card> cardGuilds = new ArrayList<>();

        //sort card base on number of player and sort card guilds
        for (Card x : this.cardBank) {
            if (x instanceof  CardAge) {
                if ( ((CardAge)x).getMinPlayer()>=nbPlayer ){
                    cardBankSorted.add(x);
                }

                if ( (((CardAge) x).getStructure()==GUILD) && (cardGuilds.size()<nbPlayer+2) ) {
                    cardGuilds.add(x);
                }
            }
            if (x instanceof CardWonder) {
                cardBankSorted.add(x);
            }
        }
        cardBankSorted.addAll(cardGuilds);
        this.cardBank =cardBankSorted;
        return true;
    }

    @Override
    public boolean cardDistribution(int age) {
        ArrayList<Card> cardsAgePack = new ArrayList<>(); //cards age that we need to use, extract from cardBank
        int i;
        if (age<0) {
            return false;
        } else{
            if (age==1) {
                //extraction cards wonder and cards age I
                ArrayList<Card> cardsWonders = new ArrayList<>();
                for (Card x : this.cardBank) {
                    if (x instanceof CardWonder) {
                        cardsWonders.add(x);
                    }
                    if ((x instanceof CardAge) && (((CardAge) x).getAge() == 1)) {
                        cardsAgePack.add(x);
                    }
                }
                this.cardBank.removeAll(cardsWonders);
                this.cardBank.removeAll(cardsAgePack);

                //distribution of card wonders and card age
                Iterator<Card> iteratorWonder = cardsWonders.iterator();
                Iterator<Card> iteratorAge = cardsAgePack.iterator();
                Card cardWonder = iteratorWonder.next();
                Card cardAge = iteratorAge.next();
                for (Player p : this.player) {
                    p.addCard(cardWonder);
                    for (i = 1; i <= 7; i++) {
                        p.addCard(cardAge);
                        if (iteratorAge.hasNext()) {
                            cardAge = iteratorAge.next();
                        }
                    }
                    if (iteratorWonder.hasNext()) {
                        cardWonder = iteratorWonder.next();
                    }
                }
            }else {
                if ((age==2) || (age==3)) {

                    //extraction cards age II
                    for (Card x : this.cardBank) {
                        if ( (x instanceof CardAge) && (((CardAge) x).getAge()== age) ) {
                            cardsAgePack.add(x);
                        }
                    }
                    this.cardBank.removeAll(cardsAgePack);

                    Iterator<Card> iteratorCardAge=cardsAgePack.iterator();
                    Card cardAge = iteratorCardAge.next();

                    //distribution to players
                    for (Player p : this.player){
                        for (i=1;i<=7;i++){
                            p.addCard(cardAge);
                            if (iteratorCardAge.hasNext()) {
                                cardAge= iteratorCardAge.next();
                            }
                        }
                    }

                }
            }
        }
        return true;
    }

    @Override
    public boolean moneyDistribution() {
        for (Player x : this.player) {
            x.moneyGet(3);
        }
        return true;
    }

    @Override
    public boolean executeActions() {
        return false;
    }

    @Override
    public boolean solveMilitaryConflicts() {
        return false;
    }

    @Override
    public boolean gameEnd() {
        this.isGamePlayed=false;
        return true;
    }
}
